### First row is header

This dropdown determines how the first row of tabular data will be read, with three options:

1. **Yes** - When selected, this option ensures the first row will be interpreted as a header row
2. **No** - When selected, this option ensures the first row will be interpreted as a regular data row
3. **Infer** - When selected, this option applies a simple heuristic to guess whether the first row is a header. Use this option when you aren't sure if your data contains a header row.

Only one option can be selected when loading data